"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "geo_match_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates an GeoMatchSet, which you use to specify which web requests you want to allow or block based on the country that the requests originate from. For example, if you're receiving a lot of requests from one or more countries and you want to block the requests, you can create an GeoMatchSet that contains those countries and then configure AWS WAF to block the requests.  To create and configure a GeoMatchSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateGeoMatchSet request.   Submit a CreateGeoMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateGeoMatchSet request.   Submit an UpdateGeoMatchSetSet request to specify the countries that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the GeoMatchSet. You can't change Name after you create the GeoMatchSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.geo_match_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.geo_match_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_geo_match_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, geo_match_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a GeoMatchSet. You can't delete a GeoMatchSet if it's still used in any Rules or if it still includes any countries. If you just want to remove a GeoMatchSet from a Rule, use UpdateRule. To permanently delete a GeoMatchSet from AWS WAF, perform the following steps:   Update the GeoMatchSet to remove any countries. For more information, see UpdateGeoMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteGeoMatchSet request.   Submit a DeleteGeoMatchSet request.

    Args:
        geo_match_set_id(str): The GeoMatchSetID of the GeoMatchSet that you want to delete. GeoMatchSetId is returned by CreateGeoMatchSet and by ListGeoMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.geo_match_set_.delete(
                ctx, geo_match_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.geo_match_set.delete geo_match_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_geo_match_set",
        op_kwargs={"GeoMatchSetId": geo_match_set_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, geo_match_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the GeoMatchSet that is specified by GeoMatchSetId.

    Args:
        geo_match_set_id(str): The GeoMatchSetId of the GeoMatchSet that you want to get. GeoMatchSetId is returned by CreateGeoMatchSet and by ListGeoMatchSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.geo_match_set_.get(ctx, geo_match_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.geo_match_set.get geo_match_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_geo_match_set",
        op_kwargs={"GeoMatchSetId": geo_match_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of GeoMatchSetSummary objects in the response.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more GeoMatchSets than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of GeoMatchSet objects. For the second and subsequent ListGeoMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of GeoMatchSet objects. Defaults to None.
        limit(int, optional): Specifies the number of GeoMatchSet objects that you want AWS WAF to return for this request. If you have more GeoMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of GeoMatchSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.geo_match_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.geo_match_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_geo_match_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, geo_match_set_id: str, change_token: str, updates: List
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes GeoMatchConstraint objects in an GeoMatchSet. For each GeoMatchConstraint object, you specify the following values:    Whether to insert or delete the object from the array. If you want to change an GeoMatchConstraint object, you delete the existing object and add a new one.   The Type. The only valid value for Type is Country.   The Value, which is a two character code for the country to add to the GeoMatchConstraint object. Valid codes are listed in GeoMatchConstraint$Value.   To create and configure an GeoMatchSet, perform the following steps:   Submit a CreateGeoMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateGeoMatchSet request.   Submit an UpdateGeoMatchSet request to specify the country that you want AWS WAF to watch for.   When you update an GeoMatchSet, you specify the country that you want to add and/or the country that you want to delete. If you want to change a country, you delete the existing country and add the new one. For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        geo_match_set_id(str): The GeoMatchSetId of the GeoMatchSet that you want to update. GeoMatchSetId is returned by CreateGeoMatchSet and by ListGeoMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of GeoMatchSetUpdate objects that you want to insert into or delete from an GeoMatchSet. For more information, see the applicable data types:    GeoMatchSetUpdate: Contains Action and GeoMatchConstraint     GeoMatchConstraint: Contains Type and Value  You can have only one Type and Value per GeoMatchConstraint. To add multiple countries, include multiple GeoMatchSetUpdate objects in your request.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.geo_match_set_.update(
                ctx, geo_match_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.geo_match_set.update geo_match_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_geo_match_set",
        op_kwargs={
            "GeoMatchSetId": geo_match_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    context_name: str,
    source: Dict,
    context_type: str,
    description: str = None,
    properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a context. A context is a lineage tracking entity that represents a logical grouping of other tracking or experiment entities. Some examples are an endpoint and a model package. For more information, see Amazon SageMaker ML Lineage Tracking.   CreateContext can only be invoked from within an SageMaker managed environment. This includes SageMaker training jobs, processing jobs, transform jobs, and SageMaker notebooks. A call to CreateContext from outside one of these environments results in an error.

    Args:
        context_name(str): The name of the context. Must be unique to your account in an Amazon Web Services Region.
        source(Dict): The source type, ID, and URI.
        context_type(str): The context type.
        description(str, optional): The description of the context. Defaults to None.
        properties(Dict, optional): A list of properties to add to the context. Defaults to None.
        tags(List, optional): A list of tags to apply to the context. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.context.create(
                ctx, context_name=value, source=value, context_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.context.create context_name=value, source=value, context_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_context",
        op_kwargs={
            "ContextName": context_name,
            "Source": source,
            "ContextType": context_type,
            "Description": description,
            "Properties": properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, context_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an context.

    Args:
        context_name(str): The name of the context to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.context.delete(ctx, context_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.context.delete context_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_context",
        op_kwargs={"ContextName": context_name},
    )


async def describe(hub, ctx, context_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a context.

    Args:
        context_name(str): The name of the context to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.context.describe(ctx, context_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.context.describe context_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_context",
        op_kwargs={"ContextName": context_name},
    )


async def list_all(
    hub,
    ctx,
    source_uri: str = None,
    context_type: str = None,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the contexts in your account and their properties.

    Args:
        source_uri(str, optional): A filter that returns only contexts with the specified source URI. Defaults to None.
        context_type(str, optional): A filter that returns only contexts of the specified type. Defaults to None.
        created_after(str, optional): A filter that returns only contexts created on or after the specified time. Defaults to None.
        created_before(str, optional): A filter that returns only contexts created on or before the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.
        next_token(str, optional): If the previous call to ListContexts didn't return the full set of contexts, the call returns a token for getting the next set of contexts. Defaults to None.
        max_results(int, optional): The maximum number of contexts to return in the response. The default value is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.context.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.context.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_contexts",
        op_kwargs={
            "SourceUri": source_uri,
            "ContextType": context_type,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    context_name: str,
    description: str = None,
    properties: Dict = None,
    properties_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a context.

    Args:
        context_name(str): The name of the context to update.
        description(str, optional): The new description for the context. Defaults to None.
        properties(Dict, optional): The new list of properties. Overwrites the current property list. Defaults to None.
        properties_to_remove(List, optional): A list of properties to remove. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.context.update(ctx, context_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.context.update context_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_context",
        op_kwargs={
            "ContextName": context_name,
            "Description": description,
            "Properties": properties,
            "PropertiesToRemove": properties_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, path: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of metadata entries about folders and objects in the specified folder.

    Args:
        path(str, optional): The path in the container from which to retrieve items. Format: <folder name>/<folder name>/<file name>. Defaults to None.
        max_results(int, optional): The maximum number of results to return per API request. For example, you submit a ListItems request with MaxResults set at 500. Although 2,000 items match your request, the service returns no more than the first 500 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.) The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 1,000 results per page. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results that you want to see. For example, you submit a ListItems request with MaxResults set at 500. The service returns the first batch of results (up to 500) and a NextToken value. To see the next batch of results, you can submit the ListItems request a second time and specify the NextToken value. Tokens expire after 15 minutes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore_data.item.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore_data.item.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore-data",
        operation="list_items",
        op_kwargs={"Path": path, "MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, server_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Describes events for a specified server. Results are ordered by time, with newest events first.   This operation is synchronous.   A ResourceNotFoundException is thrown when the server does not exist. A ValidationException is raised when parameters of the request are not valid.

    Args:
        server_name(str): The name of the server for which you want to view events.
        next_token(str, optional): NextToken is a string that is returned in some command responses. It indicates that not all entries have been returned, and that you must run at least one more request to get remaining items. To get remaining results, call DescribeEvents again, and assign the token from the previous results as the value of the nextToken parameter. If there are no more results, the response object's nextToken parameter value is null. Setting a nextToken value that was not returned in your previous results causes an InvalidNextTokenException to occur. . Defaults to None.
        max_results(int, optional): To receive a paginated response, use this parameter to specify the maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.event.describe_all(ctx, server_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.event.describe_all server_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="describe_events",
        op_kwargs={
            "ServerName": server_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, client_certificate_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the ClientCertificate resource.

    Args:
        client_certificate_id(str): [Required] The identifier of the ClientCertificate resource to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.client_certificate.delete(
                ctx, client_certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.client_certificate.delete client_certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_client_certificate",
        op_kwargs={"clientCertificateId": client_certificate_id},
    )


async def generate(hub, ctx, description: str = None, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Generates a ClientCertificate resource.

    Args:
        description(str, optional): The description of the ClientCertificate. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.client_certificate.generate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.client_certificate.generate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="generate_client_certificate",
        op_kwargs={"description": description, "tags": tags},
    )


async def get(hub, ctx, client_certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the current ClientCertificate resource.

    Args:
        client_certificate_id(str): [Required] The identifier of the ClientCertificate resource to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.client_certificate.get(
                ctx, client_certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.client_certificate.get client_certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_client_certificate",
        op_kwargs={"clientCertificateId": client_certificate_id},
    )


async def get_all(hub, ctx, position: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a collection of ClientCertificate resources.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.client_certificate.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.client_certificate.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_client_certificates",
        op_kwargs={"position": position, "limit": limit},
    )


async def update(
    hub, ctx, client_certificate_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about an ClientCertificate resource.

    Args:
        client_certificate_id(str): [Required] The identifier of the ClientCertificate resource to be updated.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.client_certificate.update(
                ctx, client_certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.client_certificate.update client_certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_client_certificate",
        op_kwargs={
            "clientCertificateId": client_certificate_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    schedule: str,
    duration: int,
    cutoff: int,
    allow_unassociated_targets: bool,
    description: str = None,
    start_date: str = None,
    end_date: str = None,
    schedule_timezone: str = None,
    schedule_offset: int = None,
    client_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new maintenance window.  The value you specify for Duration determines the specific end time for the maintenance window based on the time it begins. No maintenance window tasks are permitted to start after the resulting endtime minus the number of hours you specify for Cutoff. For example, if the maintenance window starts at 3 PM, the duration is three hours, and the value you specify for Cutoff is one hour, no maintenance window tasks can start after 5 PM.

    Args:
        name(str): The name of the maintenance window.
        description(str, optional): An optional description for the maintenance window. We recommend specifying a description to help you organize your maintenance windows. . Defaults to None.
        start_date(str, optional): The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become active. StartDate allows you to delay activation of the maintenance window until the specified future date. Defaults to None.
        end_date(str, optional): The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive. EndDate allows you to set a date and time in the future when the maintenance window will no longer run. Defaults to None.
        schedule(str): The schedule of the maintenance window in the form of a cron or rate expression.
        schedule_timezone(str, optional): The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: "America/Los_Angeles", "UTC", or "Asia/Seoul". For more information, see the Time Zone Database on the IANA website. Defaults to None.
        schedule_offset(int, optional): The number of days to wait after the date and time specified by a cron expression before running the maintenance window. For example, the following cron expression schedules a maintenance window to run on the third Tuesday of every month at 11:30 PM.  cron(30 23 ? * TUE#3 *)  If the schedule offset is 2, the maintenance window won't run until two days later. Defaults to None.
        duration(int): The duration of the maintenance window in hours.
        cutoff(int): The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution.
        allow_unassociated_targets(bool): Enables a maintenance window task to run on managed instances, even if you haven't registered those instances as targets. If enabled, then you must specify the unregistered instances (by instance ID) when you register a task with the maintenance window. If you don't enable this option, then you must specify previously-registered targets when you register a task with the maintenance window.
        client_token(str, optional): User-provided idempotency token. Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a maintenance window to identify the type of tasks it will run, the types of targets, and the environment it will run in. In this case, you could specify the following key-value pairs:    Key=TaskType,Value=AgentUpdate     Key=OS,Value=Windows     Key=Environment,Value=Production     To add tags to an existing maintenance window, use the AddTagsToResource operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.init.create(
                ctx,
                name=value,
                schedule=value,
                duration=value,
                cutoff=value,
                allow_unassociated_targets=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.init.create name=value, schedule=value, duration=value, cutoff=value, allow_unassociated_targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_maintenance_window",
        op_kwargs={
            "Name": name,
            "Description": description,
            "StartDate": start_date,
            "EndDate": end_date,
            "Schedule": schedule,
            "ScheduleTimezone": schedule_timezone,
            "ScheduleOffset": schedule_offset,
            "Duration": duration,
            "Cutoff": cutoff,
            "AllowUnassociatedTargets": allow_unassociated_targets,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, window_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a maintenance window.

    Args:
        window_id(str): The ID of the maintenance window to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.init.delete(ctx, window_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.init.delete window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_maintenance_window",
        op_kwargs={"WindowId": window_id},
    )


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the maintenance windows in an account.

    Args:
        filters(List, optional): Optional filters used to narrow down the scope of the returned maintenance windows. Supported filter keys are Name and Enabled. For example, Name=MyMaintenanceWindow and Enabled=True. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_windows",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, window_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a maintenance window.

    Args:
        window_id(str): The ID of the maintenance window for which you want to retrieve information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.init.get(ctx, window_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.init.get window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_maintenance_window",
        op_kwargs={"WindowId": window_id},
    )


async def update(
    hub,
    ctx,
    window_id: str,
    name: str = None,
    description: str = None,
    start_date: str = None,
    end_date: str = None,
    schedule: str = None,
    schedule_timezone: str = None,
    schedule_offset: int = None,
    duration: int = None,
    cutoff: int = None,
    allow_unassociated_targets: bool = None,
    enabled: bool = None,
    replace: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing maintenance window. Only specified parameters are modified.  The value you specify for Duration determines the specific end time for the maintenance window based on the time it begins. No maintenance window tasks are permitted to start after the resulting endtime minus the number of hours you specify for Cutoff. For example, if the maintenance window starts at 3 PM, the duration is three hours, and the value you specify for Cutoff is one hour, no maintenance window tasks can start after 5 PM.

    Args:
        window_id(str): The ID of the maintenance window to update.
        name(str, optional): The name of the maintenance window. Defaults to None.
        description(str, optional): An optional description for the update request. Defaults to None.
        start_date(str, optional): The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: "America/Los_Angeles", "UTC", or "Asia/Seoul". For more information, see the Time Zone Database on the IANA website. Defaults to None.
        end_date(str, optional): The date and time, in ISO-8601 Extended format, for when you want the maintenance window to become inactive. EndDate allows you to set a date and time in the future when the maintenance window will no longer run. Defaults to None.
        schedule(str, optional): The schedule of the maintenance window in the form of a cron or rate expression. Defaults to None.
        schedule_timezone(str, optional): The time zone that the scheduled maintenance window executions are based on, in Internet Assigned Numbers Authority (IANA) format. For example: "America/Los_Angeles", "UTC", or "Asia/Seoul". For more information, see the Time Zone Database on the IANA website. Defaults to None.
        schedule_offset(int, optional): The number of days to wait after the date and time specified by a cron expression before running the maintenance window. For example, the following cron expression schedules a maintenance window to run the third Tuesday of every month at 11:30 PM.  cron(30 23 ? * TUE#3 *)  If the schedule offset is 2, the maintenance window won't run until two days later. Defaults to None.
        duration(int, optional): The duration of the maintenance window in hours. Defaults to None.
        cutoff(int, optional): The number of hours before the end of the maintenance window that Amazon Web Services Systems Manager stops scheduling new tasks for execution. Defaults to None.
        allow_unassociated_targets(bool, optional): Whether targets must be registered with the maintenance window before tasks can be defined for those targets. Defaults to None.
        enabled(bool, optional): Whether the maintenance window is enabled. Defaults to None.
        replace(bool, optional): If True, then all fields that are required by the CreateMaintenanceWindow operation are also required for this API request. Optional fields that aren't specified are set to null. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.init.update(ctx, window_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.init.update window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_maintenance_window",
        op_kwargs={
            "WindowId": window_id,
            "Name": name,
            "Description": description,
            "StartDate": start_date,
            "EndDate": end_date,
            "Schedule": schedule,
            "ScheduleTimezone": schedule_timezone,
            "ScheduleOffset": schedule_offset,
            "Duration": duration,
            "Cutoff": cutoff,
            "AllowUnassociatedTargets": allow_unassociated_targets,
            "Enabled": enabled,
            "Replace": replace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    compilation_job_name: str,
    role_arn: str,
    input_config: Dict,
    output_config: Dict,
    stopping_condition: Dict,
    vpc_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a model compilation job. After the model has been compiled, Amazon SageMaker saves the resulting model artifacts to an Amazon Simple Storage Service (Amazon S3) bucket that you specify.  If you choose to host your model using Amazon SageMaker hosting services, you can use the resulting model artifacts as part of the model. You can also use the artifacts with Amazon Web Services IoT Greengrass. In that case, deploy them as an ML resource. In the request body, you provide the following:   A name for the compilation job    Information about the input model artifacts    The output location for the compiled model and the device (target) that the model runs on    The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker assumes to perform the model compilation job.    You can also provide a Tag to track the model compilation job's resource use and costs. The response body contains the CompilationJobArn for the compiled job. To stop a model compilation job, use StopCompilationJob. To get information about a particular model compilation job, use DescribeCompilationJob. To get information about multiple model compilation jobs, use ListCompilationJobs.

    Args:
        compilation_job_name(str): A name for the model compilation job. The name must be unique within the Amazon Web Services Region and within your Amazon Web Services account. .
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.  During model compilation, Amazon SageMaker needs your permission to:   Read input data from an S3 bucket   Write model artifacts to an S3 bucket   Write logs to Amazon CloudWatch Logs   Publish metrics to Amazon CloudWatch   You grant permissions for all of these tasks to an IAM role. To pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. For more information, see Amazon SageMaker Roles. .
        input_config(Dict): Provides information about the location of input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.
        output_config(Dict): Provides information about the output location for the compiled model and the target device the model runs on.
        vpc_config(Dict, optional): A VpcConfig object that specifies the VPC that you want your compilation job to connect to. Control access to your models by configuring the VPC. For more information, see Protect Compilation Jobs by Using an Amazon Virtual Private Cloud. Defaults to None.
        stopping_condition(Dict): Specifies a limit to how long a model compilation job can run. When the job reaches the time limit, Amazon SageMaker ends the compilation job. Use this API to cap model training costs.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.compilation_job.create(
                ctx,
                compilation_job_name=value,
                role_arn=value,
                input_config=value,
                output_config=value,
                stopping_condition=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.compilation_job.create compilation_job_name=value, role_arn=value, input_config=value, output_config=value, stopping_condition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_compilation_job",
        op_kwargs={
            "CompilationJobName": compilation_job_name,
            "RoleArn": role_arn,
            "InputConfig": input_config,
            "OutputConfig": output_config,
            "VpcConfig": vpc_config,
            "StoppingCondition": stopping_condition,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, compilation_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a model compilation job. To create a model compilation job, use CreateCompilationJob. To get information about multiple model compilation jobs, use ListCompilationJobs.

    Args:
        compilation_job_name(str): The name of the model compilation job that you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.compilation_job.describe(
                ctx, compilation_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.compilation_job.describe compilation_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_compilation_job",
        op_kwargs={"CompilationJobName": compilation_job_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    status_equals: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists model compilation jobs that satisfy various filters. To create a model compilation job, use CreateCompilationJob. To get information about a particular model compilation job you have created, use DescribeCompilationJob.

    Args:
        next_token(str, optional): If the result of the previous ListCompilationJobs request was truncated, the response includes a NextToken. To retrieve the next set of model compilation jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of model compilation jobs to return in the response. Defaults to None.
        creation_time_after(str, optional): A filter that returns the model compilation jobs that were created after a specified time. . Defaults to None.
        creation_time_before(str, optional): A filter that returns the model compilation jobs that were created before a specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns the model compilation jobs that were modified after a specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns the model compilation jobs that were modified before a specified time. Defaults to None.
        name_contains(str, optional): A filter that returns the model compilation jobs whose name contains a specified string. Defaults to None.
        status_equals(str, optional): A filter that retrieves model compilation jobs with a specific DescribeCompilationJobResponse$CompilationJobStatus status. Defaults to None.
        sort_by(str, optional): The field by which to sort results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.compilation_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.compilation_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_compilation_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "StatusEquals": status_equals,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def stop(hub, ctx, compilation_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a model compilation job.  To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal. This gracefully shuts the job down. If the job hasn't stopped, it sends the SIGKILL signal. When it receives a StopCompilationJob request, Amazon SageMaker changes the CompilationJobSummary$CompilationJobStatus of the job to Stopping. After Amazon SageMaker stops the job, it sets the CompilationJobSummary$CompilationJobStatus to Stopped.

    Args:
        compilation_job_name(str): The name of the model compilation job to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.compilation_job.stop(ctx, compilation_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.compilation_job.stop compilation_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_compilation_job",
        op_kwargs={"CompilationJobName": compilation_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, configuration_aggregator_name: str, resource_identifiers: List
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current configuration items for resources that are present in your AWS Config aggregator. The operation also returns a list of resources that are not processed in the current request. If there are no unprocessed resources, the operation returns an empty unprocessedResourceIdentifiers list.     The API does not return results for deleted resources.    The API does not return tags and relationships.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        resource_identifiers(List): A list of aggregate ResourceIdentifiers objects. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.get.aggregate_resource_config.batch(
                ctx, configuration_aggregator_name=value, resource_identifiers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.get.aggregate_resource_config.batch configuration_aggregator_name=value, resource_identifiers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="batch_get_aggregate_resource_config",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "ResourceIdentifiers": resource_identifiers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    first_name: str,
    display_name: str = None,
    last_name: str = None,
    phone_number: str = None,
    phone_numbers: List = None,
    sip_addresses: List = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a contact with the specified details.

    Args:
        display_name(str, optional): The name of the contact to display on the console. Defaults to None.
        first_name(str): The first name of the contact that is used to call the contact on the device.
        last_name(str, optional): The last name of the contact that is used to call the contact on the device. Defaults to None.
        phone_number(str, optional): The phone number of the contact in E.164 format. The phone number type defaults to WORK. You can specify PhoneNumber or PhoneNumbers. We recommend that you use PhoneNumbers, which lets you specify the phone number type and multiple numbers. Defaults to None.
        phone_numbers(List, optional): The list of phone numbers for the contact. Defaults to None.
        sip_addresses(List, optional): The list of SIP addresses for the contact. Defaults to None.
        client_request_token(str, optional): A unique, user-specified identifier for this request that ensures idempotency. Defaults to None.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.init.create(ctx, first_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.init.create first_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_contact",
        op_kwargs={
            "DisplayName": display_name,
            "FirstName": first_name,
            "LastName": last_name,
            "PhoneNumber": phone_number,
            "PhoneNumbers": phone_numbers,
            "SipAddresses": sip_addresses,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, contact_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a contact by the contact ARN.

    Args:
        contact_arn(str): The ARN of the contact to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.init.delete(ctx, contact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.init.delete contact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_contact",
        op_kwargs={"ContactArn": contact_arn},
    )


async def get(hub, ctx, contact_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the contact details by the contact ARN.

    Args:
        contact_arn(str): The ARN of the contact for which to request details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.init.get(ctx, contact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.init.get contact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_contact",
        op_kwargs={"ContactArn": contact_arn},
    )


async def search(
    hub,
    ctx,
    filters: List = None,
    sort_criteria: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches contacts and lists the ones that meet a set of filter and sort criteria.

    Args:
        filters(List, optional): The filters to use to list a specified set of address books. The supported filter keys are DisplayName, FirstName, LastName, and AddressBookArns. Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of contacts. The supported sort keys are DisplayName, FirstName, and LastName. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response only includes results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_contacts",
        op_kwargs={
            "Filters": filters,
            "SortCriteria": sort_criteria,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    contact_arn: str,
    display_name: str = None,
    first_name: str = None,
    last_name: str = None,
    phone_number: str = None,
    phone_numbers: List = None,
    sip_addresses: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the contact details by the contact ARN.

    Args:
        contact_arn(str): The ARN of the contact to update.
        display_name(str, optional): The updated display name of the contact. Defaults to None.
        first_name(str, optional): The updated first name of the contact. Defaults to None.
        last_name(str, optional): The updated last name of the contact. Defaults to None.
        phone_number(str, optional): The updated phone number of the contact. The phone number type defaults to WORK. You can either specify PhoneNumber or PhoneNumbers. We recommend that you use PhoneNumbers, which lets you specify the phone number type and multiple numbers. Defaults to None.
        phone_numbers(List, optional): The list of phone numbers for the contact. Defaults to None.
        sip_addresses(List, optional): The list of SIP addresses for the contact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.init.update(ctx, contact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.init.update contact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_contact",
        op_kwargs={
            "ContactArn": contact_arn,
            "DisplayName": display_name,
            "FirstName": first_name,
            "LastName": last_name,
            "PhoneNumber": phone_number,
            "PhoneNumbers": phone_numbers,
            "SipAddresses": sip_addresses,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    cluster_version: str = None,
    node_type: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of orderable cluster options. Before you create a new cluster you can use this operation to find what options are available, such as the EC2 Availability Zones (AZ) in the specific Amazon Web Services Region that you can specify, and the node types you can request. The node types differ by available storage, memory, CPU and price. With the cost involved you might want to obtain a list of cluster options in the specific region and specify values when creating a cluster. For more information about managing clusters, go to Amazon Redshift Clusters in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_version(str, optional): The version filter value. Specify this parameter to show only the available offerings matching the specified version. Default: All versions. Constraints: Must be one of the version returned from DescribeClusterVersions. Defaults to None.
        node_type(str, optional): The node type filter value. Specify this parameter to show only the available offerings matching the specified node type. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeOrderableClusterOptions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.orderable_cluster_option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.orderable_cluster_option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_orderable_cluster_options",
        op_kwargs={
            "ClusterVersion": cluster_version,
            "NodeType": node_type,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the shareable resource types supported by AWS RAM.

    Args:
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.type_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.type.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="list_resource_types",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    project_name: str,
    output_config: Dict,
    description: str = None,
    client_token: str = None,
    kms_key_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of a model within an an Amazon Lookout for Vision project. CreateModel is an asynchronous operation in which Amazon Lookout for Vision trains, tests, and evaluates a new version of a model.  To get the current status, check the Status field returned in the response from DescribeModel. If the project has a single dataset, Amazon Lookout for Vision internally splits the dataset to create a training and a test dataset. If the project has a training and a test dataset, Lookout for Vision uses the respective datasets to train and test the model.  After training completes, the evaluation metrics are stored at the location specified in OutputConfig.  This operation requires permissions to perform the lookoutvision:CreateModel operation. If you want to tag your model, you also require permission to the lookoutvision:TagResource operation.

    Args:
        project_name(str): The name of the project in which you want to create a model version.
        description(str, optional): A description for the version of the model. Defaults to None.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to CreateModel completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from CreateModel. In this case, safely retry your call to CreateModel by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to CreateModel. An idempotency token is active for 8 hours. Defaults to None.
        output_config(Dict): The location where Amazon Lookout for Vision saves the training results.
        kms_key_id(str, optional): The identifier for your AWS Key Management Service (AWS KMS) customer master key (CMK). The key is used to encrypt training and test images copied into the service for model training. Your source images are unaffected. If this parameter is not specified, the copied images are encrypted by a key that AWS owns and manages. Defaults to None.
        tags(List, optional): A set of tags (key-value pairs) that you want to attach to the model. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.create(
                ctx, project_name=value, output_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.create project_name=value, output_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="create_model",
        op_kwargs={
            "ProjectName": project_name,
            "Description": description,
            "ClientToken": client_token,
            "OutputConfig": output_config,
            "KmsKeyId": kms_key_id,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, project_name: str, model_version: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Lookout for Vision model. You can't delete a running model. To stop a running model, use the StopModel operation. It might take a few seconds to delete a model. To determine if a model has been deleted, call ListProjects and check if the version of the model (ModelVersion) is in the Models array.  This operation requires permissions to perform the lookoutvision:DeleteModel operation.

    Args:
        project_name(str): The name of the project that contains the model that you want to delete.
        model_version(str): The version of the model that you want to delete.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to DeleteModel completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from DeleteModel. In this case, safely retry your call to DeleteModel by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to DeleteModel. An idempotency token is active for 8 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.delete(
                ctx, project_name=value, model_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.delete project_name=value, model_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="delete_model",
        op_kwargs={
            "ProjectName": project_name,
            "ModelVersion": model_version,
            "ClientToken": client_token,
        },
    )


async def describe(hub, ctx, project_name: str, model_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a version of an Amazon Lookout for Vision model. This operation requires permissions to perform the lookoutvision:DescribeModel operation.

    Args:
        project_name(str): The project that contains the version of a model that you want to describe.
        model_version(str): The version of the model that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.describe(
                ctx, project_name=value, model_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.describe project_name=value, model_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="describe_model",
        op_kwargs={"ProjectName": project_name, "ModelVersion": model_version},
    )


async def list_all(
    hub, ctx, project_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a model in an Amazon Lookout for Vision project. This operation requires permissions to perform the lookoutvision:ListModels operation.

    Args:
        project_name(str): The name of the project that contains the model versions that you want to list.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Lookout for Vision returns a pagination token in the response. You can use this pagination token to retrieve the next set of models. Defaults to None.
        max_results(int, optional): The maximum number of results to return per paginated call. The largest value you can specify is 100. If you specify a value greater than 100, a ValidationException error occurs. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.list_all(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.list_all project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="list_models",
        op_kwargs={
            "ProjectName": project_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    project_name: str,
    model_version: str,
    min_inference_units: int,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the running of the version of an Amazon Lookout for Vision model. Starting a model takes a while to complete. To check the current state of the model, use DescribeModel. A model is ready to use when its status is HOSTED. Once the model is running, you can detect custom labels in new images by calling DetectAnomalies.  You are charged for the amount of time that the model is running. To stop a running model, call StopModel.  This operation requires permissions to perform the lookoutvision:StartModel operation.

    Args:
        project_name(str): The name of the project that contains the model that you want to start.
        model_version(str): The version of the model that you want to start.
        min_inference_units(int): The minimum number of inference units to use. A single inference unit represents 1 hour of processing and can support up to 5 Transaction Pers Second (TPS). Use a higher number to increase the TPS throughput of your model. You are charged for the number of inference units that you use. .
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to StartModel completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from StartModel. In this case, safely retry your call to StartModel by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to StartModel. An idempotency token is active for 8 hours. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.start(
                ctx, project_name=value, model_version=value, min_inference_units=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.start project_name=value, model_version=value, min_inference_units=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="start_model",
        op_kwargs={
            "ProjectName": project_name,
            "ModelVersion": model_version,
            "MinInferenceUnits": min_inference_units,
            "ClientToken": client_token,
        },
    )


async def stop(
    hub, ctx, project_name: str, model_version: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Stops the hosting of a running model. The operation might take a while to complete. To check the current status, call DescribeModel.  After the model hosting stops, the Status of the model is TRAINED. This operation requires permissions to perform the lookoutvision:StopModel operation.

    Args:
        project_name(str): The name of the project that contains the model that you want to stop.
        model_version(str): The version of the model that you want to stop.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to StopModel completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from StopModel. In this case, safely retry your call to StopModel by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to StopModel. An idempotency token is active for 8 hours. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.model.stop(
                ctx, project_name=value, model_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.model.stop project_name=value, model_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="stop_model",
        op_kwargs={
            "ProjectName": project_name,
            "ModelVersion": model_version,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    description: str = None,
    resource_lifecycle_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an application that has one configuration template named default and no application versions.

    Args:
        application_name(str): The name of the application. Must be unique within your account.
        description(str, optional): Your description of the application. Defaults to None.
        resource_lifecycle_config(Dict, optional): Specifies an application resource lifecycle configuration to prevent your application from accumulating too many versions. Defaults to None.
        tags(List, optional): Specifies the tags applied to the application. Elastic Beanstalk applies these tags only to the application. Environments that you create in the application don't inherit the tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.init.create(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.init.create application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_application",
        op_kwargs={
            "ApplicationName": application_name,
            "Description": description,
            "ResourceLifecycleConfig": resource_lifecycle_config,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, application_name: str, terminate_env_by_force: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified application along with all associated versions and configurations. The application versions will not be deleted from your Amazon S3 bucket.  You cannot delete an application that has a running environment.

    Args:
        application_name(str): The name of the application to delete.
        terminate_env_by_force(bool, optional): When set to true, running environments will be terminated before deleting the application. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.init.delete(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.init.delete application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="delete_application",
        op_kwargs={
            "ApplicationName": application_name,
            "TerminateEnvByForce": terminate_env_by_force,
        },
    )


async def describe_all(hub, ctx, application_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the descriptions of existing applications.

    Args:
        application_names(List, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to only include those with the specified names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_applications",
        op_kwargs={"ApplicationNames": application_names},
    )


async def update(hub, ctx, application_name: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified application to have the specified properties.  If a property (for example, description) is not provided, the value remains unchanged. To clear these properties, specify an empty string.

    Args:
        application_name(str): The name of the application to update. If no such application is found, UpdateApplication returns an InvalidParameterValue error. .
        description(str, optional): A new description for the application. Default: If not specified, AWS Elastic Beanstalk does not update the description. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.init.update(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.init.update application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_application",
        op_kwargs={"ApplicationName": application_name, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    container_type: str,
    name: str,
    semantic_version: str,
    components: List,
    parent_image: str,
    target_repository: Dict,
    client_token: str,
    description: str = None,
    instance_configuration: Dict = None,
    dockerfile_template_data: str = None,
    dockerfile_template_uri: str = None,
    platform_override: str = None,
    image_os_version_override: str = None,
    tags: Dict = None,
    working_directory: str = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new container recipe. Container recipes define how images are configured, tested, and assessed.

    Args:
        container_type(str): The type of container to create.
        name(str): The name of the container recipe.
        description(str, optional): The description of the container recipe. Defaults to None.
        semantic_version(str): The semantic version of the container recipe. This version follows the semantic version syntax.  The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.  Assignment: For the first three nodes you can assign any positive integer value, including zero, with an upper limit of 2^30-1, or 1073741823 for each node. Image Builder automatically assigns the build number, and that is not open for updates.  Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01. .
        components(List): Components for build and test that are included in the container recipe.
        instance_configuration(Dict, optional): A group of options that can be used to configure an instance for building and testing container images. Defaults to None.
        dockerfile_template_data(str, optional): The Dockerfile template used to build your image as an inline data blob. Defaults to None.
        dockerfile_template_uri(str, optional): The Amazon S3 URI for the Dockerfile that will be used to build your container image. Defaults to None.
        platform_override(str, optional): Specifies the operating system platform when you use a custom source image. Defaults to None.
        image_os_version_override(str, optional): Specifies the operating system version for the source image. Defaults to None.
        parent_image(str): The source image for the container recipe.
        tags(Dict, optional): Tags that are attached to the container recipe. Defaults to None.
        working_directory(str, optional): The working directory for use during build and test workflows. Defaults to None.
        target_repository(Dict): The destination repository for the container image.
        kms_key_id(str, optional): Identifies which KMS key is used to encrypt the container image. Defaults to None.
        client_token(str): The client token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.init.create(
                ctx,
                container_type=value,
                name=value,
                semantic_version=value,
                components=value,
                parent_image=value,
                target_repository=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.init.create container_type=value, name=value, semantic_version=value, components=value, parent_image=value, target_repository=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_container_recipe",
        op_kwargs={
            "containerType": container_type,
            "name": name,
            "description": description,
            "semanticVersion": semantic_version,
            "components": components,
            "instanceConfiguration": instance_configuration,
            "dockerfileTemplateData": dockerfile_template_data,
            "dockerfileTemplateUri": dockerfile_template_uri,
            "platformOverride": platform_override,
            "imageOsVersionOverride": image_os_version_override,
            "parentImage": parent_image,
            "tags": tags,
            "workingDirectory": working_directory,
            "targetRepository": target_repository,
            "kmsKeyId": kms_key_id,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, container_recipe_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a container recipe.

    Args:
        container_recipe_arn(str): The Amazon Resource Name (ARN) of the container recipe to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.init.delete(
                ctx, container_recipe_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.init.delete container_recipe_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_container_recipe",
        op_kwargs={"containerRecipeArn": container_recipe_arn},
    )


async def get(hub, ctx, container_recipe_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a container recipe.

    Args:
        container_recipe_arn(str): The Amazon Resource Name (ARN) of the container recipe to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.init.get(
                ctx, container_recipe_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.init.get container_recipe_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_container_recipe",
        op_kwargs={"containerRecipeArn": container_recipe_arn},
    )


async def list_all(
    hub,
    ctx,
    owner: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of container recipes.

    Args:
        owner(str, optional): Returns container recipes belonging to the specified owner, that have been shared with you. You can omit this field to return container recipes belonging to your account. Defaults to None.
        filters(List, optional): Request filters that are used to narrow the list of container images that are returned. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the list. Defaults to None.
        next_token(str, optional): Provides a token for pagination, which determines where to begin the next set of results when the current set reaches the maximum for one request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_container_recipes",
        op_kwargs={
            "owner": owner,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic Regional documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the web ACL for the specified resource, either an application load balancer or Amazon API Gateway stage.

    Args:
        resource_arn(str): The ARN (Amazon Resource Name) of the resource for which to get the web ACL, either an application load balancer or Amazon API Gateway stage. The ARN should be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Amazon API Gateway stage: arn:aws:apigateway:region::/restapis/api-id/stages/stage-name    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.for_resource.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.for_resource.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_web_acl_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, secret_id: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Attaches one or more tags, each consisting of a key name and a value, to the specified secret. Tags are part of the secret's overall metadata, and are not associated with any specific version of the secret. This operation only appends tags to the existing list of tags. To remove tags, you must use UntagResource. The following basic restrictions apply to tags:   Maximum number of tags per secret—50   Maximum key length—127 Unicode characters in UTF-8   Maximum value length—255 Unicode characters in UTF-8   Tag keys and values are case sensitive.   Do not use the aws: prefix in your tag names or values because Amazon Web Services reserves it for Amazon Web Services use. You can't edit or delete tag names or values with this prefix. Tags with this prefix do not count against your tags per secret limit.   If you use your tagging schema across multiple services and resources, remember other services might have restrictions on allowed characters. Generally allowed characters: letters, spaces, and numbers representable in UTF-8, plus the following special characters: + - = . _ : / @.    If you use tags as part of your security strategy, then adding or removing a tag can change permissions. If successfully completing this operation would result in you losing your permissions for this secret, then the operation is blocked and returns an Access Denied error.   Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:TagResource    Related operations    To remove one or more tags from the collection attached to a secret, use UntagResource.   To view the list of tags attached to a secret, use DescribeSecret.

    Args:
        secret_id(str): The identifier for the secret that you want to attach tags to. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        tags(List): The tags to attach to the secret. Each element in the list consists of a Key and a Value. This parameter to the API requires a JSON text string argument. For information on how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters in the CLI User Guide. For the CLI, you can also use the syntax: --Tags Key="Key1",Value="Value1" Key="Key2",Value="Value2"[,…] .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.init.tag(
                ctx, secret_id=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.init.tag secret_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="tag_resource",
        op_kwargs={"SecretId": secret_id, "Tags": tags},
    )


async def untag(hub, ctx, secret_id: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified secret. This operation is idempotent. If a requested tag is not attached to the secret, no error is returned and the secret metadata is unchanged.  If you use tags as part of your security strategy, then removing a tag can change permissions. If successfully completing this operation would result in you losing your permissions for this secret, then the operation is blocked and returns an Access Denied error.   Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:UntagResource    Related operations    To add one or more tags to the collection attached to a secret, use TagResource.   To view the list of tags attached to a secret, use DescribeSecret.

    Args:
        secret_id(str): The identifier for the secret that you want to remove tags from. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        tag_keys(List): A list of tag key names to remove from the secret. You don't specify the value. Both the key and its associated value are removed. This parameter to the API requires a JSON text string argument. For information on how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters in the CLI User Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.init.untag(
                ctx, secret_id=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.init.untag secret_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="untag_resource",
        op_kwargs={"SecretId": secret_id, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def get(hub, ctx, catalog_name: str, database_name: str, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns table metadata for the specified catalog, database, and table.

    Args:
        catalog_name(str): The name of the data catalog that contains the database and table metadata to return.
        database_name(str): The name of the database that contains the table metadata to return.
        table_name(str): The name of the table for which metadata is returned.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.table_metadata.get(
                ctx, catalog_name=value, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.table_metadata.get catalog_name=value, database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_table_metadata",
        op_kwargs={
            "CatalogName": catalog_name,
            "DatabaseName": database_name,
            "TableName": table_name,
        },
    )


async def list_(
    hub,
    ctx,
    catalog_name: str,
    database_name: str,
    expression: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the metadata for the tables in the specified data catalog database.

    Args:
        catalog_name(str): The name of the data catalog for which table metadata should be returned.
        database_name(str): The name of the database for which table metadata should be returned.
        expression(str, optional): A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed. Defaults to None.
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): Specifies the maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.table_metadata.list(
                ctx, catalog_name=value, database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.table_metadata.list catalog_name=value, database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_table_metadata",
        op_kwargs={
            "CatalogName": catalog_name,
            "DatabaseName": database_name,
            "Expression": expression,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_id: str,
    model_type: str,
    training_data_source: str,
    training_data_schema: Dict,
    external_events_detail: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of the model using the specified model type and model id.

    Args:
        model_id(str): The model ID. .
        model_type(str): The model type.
        training_data_source(str): The training data source location in Amazon S3. .
        training_data_schema(Dict): The training data schema.
        external_events_detail(Dict, optional): Details for the external events data used for model version training. Required if trainingDataSource is EXTERNAL_EVENTS. Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.init.create(
                ctx,
                model_id=value,
                model_type=value,
                training_data_source=value,
                training_data_schema=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.init.create model_id=value, model_type=value, training_data_source=value, training_data_schema=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_model_version",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "trainingDataSource": training_data_source,
            "trainingDataSchema": training_data_schema,
            "externalEventsDetail": external_events_detail,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, model_id: str, model_type: str, model_version_number: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a model version. You can delete models and model versions in Amazon Fraud Detector, provided that they are not associated with a detector version.  When you delete a model version, Amazon Fraud Detector permanently deletes that model version and the data is no longer stored in Amazon Fraud Detector.

    Args:
        model_id(str): The model ID of the model version to delete.
        model_type(str): The model type of the model version to delete.
        model_version_number(str): The model version number of the model version to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.init.delete(
                ctx, model_id=value, model_type=value, model_version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.init.delete model_id=value, model_type=value, model_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_model_version",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "modelVersionNumber": model_version_number,
        },
    )


async def describe_all(
    hub,
    ctx,
    model_id: str = None,
    model_version_number: str = None,
    model_type: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all of the model versions for the specified model type or for the specified model type and model ID. You can also get details for a single, specified model version.

    Args:
        model_id(str, optional): The model ID. Defaults to None.
        model_version_number(str, optional): The model version number. Defaults to None.
        model_type(str, optional): The model type. Defaults to None.
        next_token(str, optional): The next token from the previous results. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="describe_model_versions",
        op_kwargs={
            "modelId": model_id,
            "modelVersionNumber": model_version_number,
            "modelType": model_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def get(
    hub, ctx, model_id: str, model_type: str, model_version_number: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details of the specified model version.

    Args:
        model_id(str): The model ID.
        model_type(str): The model type.
        model_version_number(str): The model version number.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.init.get(
                ctx, model_id=value, model_type=value, model_version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.init.get model_id=value, model_type=value, model_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_model_version",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "modelVersionNumber": model_version_number,
        },
    )


async def update(
    hub,
    ctx,
    model_id: str,
    model_type: str,
    major_version_number: str,
    external_events_detail: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a model version. Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03.

    Args:
        model_id(str): The model ID.
        model_type(str): The model type.
        major_version_number(str): The major version number.
        external_events_detail(Dict, optional): The event details. Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.model.version.init.update(
                ctx, model_id=value, model_type=value, major_version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.model.version.init.update model_id=value, model_type=value, major_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_model_version",
        op_kwargs={
            "modelId": model_id,
            "modelType": model_type,
            "majorVersionNumber": major_version_number,
            "externalEventsDetail": external_events_detail,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(hub, ctx, distribution_name: str, certificate_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches an SSL/TLS certificate to your Amazon Lightsail content delivery network (CDN) distribution. After the certificate is attached, your distribution accepts HTTPS traffic for all of the domains that are associated with the certificate. Use the CreateCertificate action to create a certificate that you can attach to your distribution.  Only certificates created in the us-east-1 AWS Region can be attached to Lightsail distributions. Lightsail distributions are global resources that can reference an origin in any AWS Region, and distribute its content globally. However, all distributions are located in the us-east-1 Region.

    Args:
        distribution_name(str): The name of the distribution that the certificate will be attached to. Use the GetDistributions action to get a list of distribution names that you can specify.
        certificate_name(str): The name of the certificate to attach to a distribution. Only certificates with a status of ISSUED can be attached to a distribution. Use the GetCertificates action to get a list of certificate names that you can specify.  This is the name of the certificate resource type and is used only to reference the certificate in other API actions. It can be different than the domain name of the certificate. For example, your certificate name might be WordPress-Blog-Certificate and the domain name of the certificate might be example.com. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.certificate.to_distribution.attach(
                ctx, distribution_name=value, certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.certificate.to_distribution.attach distribution_name=value, certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="attach_certificate_to_distribution",
        op_kwargs={
            "distributionName": distribution_name,
            "certificateName": certificate_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def search(
    hub,
    ctx,
    expression: List,
    next_token: str = None,
    max_results: int = None,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation allows a search on TABLE resources by LFTags. This will be used by admins who want to grant user permissions on certain LFTags. Before making a grant, the admin can use SearchTablesByLFTags to find all resources where the given LFTags are valid to verify whether the returned resources can be shared.

    Args:
        next_token(str, optional): A continuation token, if this is not the first call to retrieve this list. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        expression(List): A list of conditions (LFTag structures) to search for in table resources.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.table_by_lf_tag.search(ctx, expression=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.table_by_lf_tag.search expression=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="search_tables_by_lf_tags",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CatalogId": catalog_id,
            "Expression": expression,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    profile_name: str,
    action: str,
    principal: str,
    statement_id: str,
    profile_version: str = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds cross-account permissions to a signing profile.

    Args:
        profile_name(str): The human-readable name of the signing profile.
        profile_version(str, optional): The version of the signing profile. Defaults to None.
        action(str): The AWS Signer action permitted as part of cross-account permissions.
        principal(str): The AWS principal receiving cross-account permissions. This may be an IAM role or another AWS account ID.
        revision_id(str, optional): A unique identifier for the current profile revision. Defaults to None.
        statement_id(str): A unique identifier for the cross-account permission statement.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.profile_permission.add(
                ctx, profile_name=value, action=value, principal=value, statement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.profile_permission.add profile_name=value, action=value, principal=value, statement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="add_profile_permission",
        op_kwargs={
            "profileName": profile_name,
            "profileVersion": profile_version,
            "action": action,
            "principal": principal,
            "revisionId": revision_id,
            "statementId": statement_id,
        },
    )


async def list_all(hub, ctx, profile_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the cross-account permissions associated with a signing profile.

    Args:
        profile_name(str): Name of the signing profile containing the cross-account permissions.
        next_token(str, optional): String for specifying the next set of paginated results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.profile_permission.list_all(ctx, profile_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.profile_permission.list_all profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="list_profile_permissions",
        op_kwargs={"profileName": profile_name, "nextToken": next_token},
    )


async def remove(
    hub, ctx, profile_name: str, revision_id: str, statement_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes cross-account permissions from a signing profile.

    Args:
        profile_name(str): A human-readable name for the signing profile with permissions to be removed.
        revision_id(str): An identifier for the current revision of the signing profile permissions.
        statement_id(str): A unique identifier for the cross-account permissions statement.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.signer.profile_permission.remove(
                ctx, profile_name=value, revision_id=value, statement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.signer.profile_permission.remove profile_name=value, revision_id=value, statement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="signer",
        operation="remove_profile_permission",
        op_kwargs={
            "profileName": profile_name,
            "revisionId": revision_id,
            "statementId": statement_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def discover(
    hub,
    ctx,
    resource_arn: str = None,
    role_arn: str = None,
    input_starting_position_configuration: Dict = None,
    s3_configuration: Dict = None,
    input_processing_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Infers a schema by evaluating sample records on the specified streaming source (Amazon Kinesis stream or Amazon Kinesis Firehose delivery stream) or S3 object. In the response, the operation returns the inferred schema and also the sample records that the operation used to infer the schema.  You can use the inferred schema when configuring a streaming source for your application. For conceptual information, see Configuring Application Input. Note that when you create an application using the Amazon Kinesis Analytics console, the console uses this operation to infer a schema and show it in the console user interface.   This operation requires permissions to perform the kinesisanalytics:DiscoverInputSchema action.

    Args:
        resource_arn(str, optional): Amazon Resource Name (ARN) of the streaming source. Defaults to None.
        role_arn(str, optional): ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. Defaults to None.
        input_starting_position_configuration(Dict, optional): Point at which you want Amazon Kinesis Analytics to start reading records from the specified streaming source discovery purposes. Defaults to None.
        s3_configuration(Dict, optional): Specify this parameter to discover a schema from data in an Amazon S3 object. Defaults to None.
        input_processing_configuration(Dict, optional): The InputProcessingConfiguration to use to preprocess the records before discovering the schema of the records. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.input_schema.discover(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.input_schema.discover
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="discover_input_schema",
        op_kwargs={
            "ResourceARN": resource_arn,
            "RoleARN": role_arn,
            "InputStartingPositionConfiguration": input_starting_position_configuration,
            "S3Configuration": s3_configuration,
            "InputProcessingConfiguration": input_processing_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, acknowledge_action_requests: List) -> Dict:
    r"""
    **Autogenerated function**

    Acknowledges one or more alarms. The alarms change to the ACKNOWLEDGED state after you acknowledge them.

    Args:
        acknowledge_action_requests(List): The list of acknowledge action requests. You can specify up to 10 requests per operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent_data.acknowledge_alarm.batch(
                ctx, acknowledge_action_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent_data.acknowledge_alarm.batch acknowledge_action_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents-data",
        operation="batch_acknowledge_alarm",
        op_kwargs={"acknowledgeActionRequests": acknowledge_action_requests},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(
    hub,
    ctx,
    configuration_name: str,
    players: List,
    ticket_id: str = None,
    game_session_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Finds new players to fill open slots in currently running game sessions. The backfill match process is essentially identical to the process of forming new matches. Backfill requests use the same matchmaker that was used to make the original match, and they provide matchmaking data for all players currently in the game session. FlexMatch uses this information to select new players so that backfilled match continues to meet the original match requirements.  When using FlexMatch with GameLift managed hosting, you can request a backfill match from a client service by calling this operation with a GameSession identifier. You also have the option of making backfill requests directly from your game server. In response to a request, FlexMatch creates player sessions for the new players, updates the GameSession resource, and sends updated matchmaking data to the game server. You can request a backfill match at any point after a game session is started. Each game session can have only one active backfill request at a time; a subsequent request automatically replaces the earlier request. When using FlexMatch as a standalone component, request a backfill match by calling this operation without a game session identifier. As with newly formed matches, matchmaking results are returned in a matchmaking event so that your game can update the game session that is being backfilled. To request a backfill match, specify a unique ticket ID, the original matchmaking configuration, and matchmaking data for all current players in the game session being backfilled. Optionally, specify the GameSession ARN. If successful, a match backfill ticket is created and returned with status set to QUEUED. Track the status of backfill tickets using the same method for tracking tickets for new matches.  Learn more    Backfill existing games with FlexMatch    Matchmaking events (reference)   How GameLift FlexMatch works   Related actions   StartMatchmaking | DescribeMatchmaking | StopMatchmaking | AcceptMatch | StartMatchBackfill | All APIs by task

    Args:
        ticket_id(str, optional): A unique identifier for a matchmaking ticket. If no ticket ID is specified here, Amazon GameLift will generate one in the form of a UUID. Use this identifier to track the match backfill ticket status and retrieve match results. Defaults to None.
        configuration_name(str): Name of the matchmaker to use for this request. You can use either the configuration name or ARN value. The ARN of the matchmaker that was used with the original game session is listed in the GameSession object, MatchmakerData property.
        game_session_arn(str, optional): A unique identifier for the game session. Use the game session ID. When using FlexMatch as a standalone matchmaking solution, this parameter is not needed. . Defaults to None.
        players(List): Match information on all players that are currently assigned to the game session. This information is used by the matchmaker to find new players and add them to the existing game.   PlayerID, PlayerAttributes, Team -- This information is maintained in the GameSession object, MatchmakerData property, for all players who are currently assigned to the game session. The matchmaker data is in JSON syntax, formatted as a string. For more details, see  Match Data.    LatencyInMs -- If the matchmaker uses player latency, include a latency value, in milliseconds, for the Region that the game session is currently in. Do not include latency values for any other Region.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.match.backfill.start(
                ctx, configuration_name=value, players=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.match.backfill.start configuration_name=value, players=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="start_match_backfill",
        op_kwargs={
            "TicketId": ticket_id,
            "ConfigurationName": configuration_name,
            "GameSessionArn": game_session_arn,
            "Players": players,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    vpc_peering_connection_id: str,
    accepter_peering_connection_options: Dict = None,
    dry_run: bool = None,
    requester_peering_connection_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the VPC peering connection options on one side of a VPC peering connection. You can do the following:   Enable/disable communication over the peering connection between an EC2-Classic instance that's linked to your VPC (using ClassicLink) and instances in the peer VPC.   Enable/disable communication over the peering connection between instances in your VPC and an EC2-Classic instance that's linked to the peer VPC.   Enable/disable the ability to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.   If the peered VPCs are in the same Amazon Web Services account, you can enable DNS resolution for queries from the local VPC. This ensures that queries from the local VPC resolve to private IP addresses in the peer VPC. This option is not available if the peered VPCs are in different different Amazon Web Services accounts or different Regions. For peered VPCs in different Amazon Web Services accounts, each Amazon Web Services account owner must initiate a separate request to modify the peering connection options. For inter-region peering connections, you must use the Region for the requester VPC to modify the requester VPC peering options and the Region for the accepter VPC to modify the accepter VPC peering options. To verify which VPCs are the accepter and the requester for a VPC peering connection, use the DescribeVpcPeeringConnections command.

    Args:
        accepter_peering_connection_options(Dict, optional): The VPC peering connection options for the accepter VPC. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        requester_peering_connection_options(Dict, optional): The VPC peering connection options for the requester VPC. Defaults to None.
        vpc_peering_connection_id(str): The ID of the VPC peering connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.peering_connection.option.modify(
                ctx, vpc_peering_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.peering_connection.option.modify vpc_peering_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_peering_connection_options",
        op_kwargs={
            "AccepterPeeringConnectionOptions": accepter_peering_connection_options,
            "DryRun": dry_run,
            "RequesterPeeringConnectionOptions": requester_peering_connection_options,
            "VpcPeeringConnectionId": vpc_peering_connection_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, insight_id: str, next_token: str = None, locale: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of a specified insight's recommendations. Each recommendation includes a list of related metrics and a list of related events.

    Args:
        insight_id(str):  The ID of the requested insight. .
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        locale(str, optional): A locale that specifies the language to use for recommendations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.recommendation.list_all(ctx, insight_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.recommendation.list_all insight_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="list_recommendations",
        op_kwargs={"InsightId": insight_id, "NextToken": next_token, "Locale": locale},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_cluster_parameter_group_identifier: str,
    target_db_cluster_parameter_group_identifier: str,
    target_db_cluster_parameter_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified DB cluster parameter group.

    Args:
        source_db_cluster_parameter_group_identifier(str): The identifier or Amazon Resource Name (ARN) for the source DB cluster parameter group. For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN). Constraints:   Must specify a valid DB cluster parameter group.   If the source DB cluster parameter group is in the same Amazon Region as the copy, specify a valid DB parameter group identifier, for example my-db-cluster-param-group, or a valid ARN.   If the source DB parameter group is in a different Amazon Region than the copy, specify a valid DB cluster parameter group ARN, for example arn:aws:rds:us-east-1:123456789012:cluster-pg:custom-cluster-group1.  .
        target_db_cluster_parameter_group_identifier(str): The identifier for the copied DB cluster parameter group. Constraints:   Cannot be null, empty, or blank   Must contain from 1 to 255 letters, numbers, or hyphens   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens   Example: my-cluster-param-group1 .
        target_db_cluster_parameter_group_description(str): A description for the copied DB cluster parameter group.
        tags(List, optional): The tags to be assigned to the copied DB cluster parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.copy(
                ctx,
                source_db_cluster_parameter_group_identifier=value,
                target_db_cluster_parameter_group_identifier=value,
                target_db_cluster_parameter_group_description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.copy source_db_cluster_parameter_group_identifier=value, target_db_cluster_parameter_group_identifier=value, target_db_cluster_parameter_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="copy_db_cluster_parameter_group",
        op_kwargs={
            "SourceDBClusterParameterGroupIdentifier": source_db_cluster_parameter_group_identifier,
            "TargetDBClusterParameterGroupIdentifier": target_db_cluster_parameter_group_identifier,
            "TargetDBClusterParameterGroupDescription": target_db_cluster_parameter_group_description,
            "Tags": tags,
        },
    )


async def create(
    hub,
    ctx,
    db_cluster_parameter_group_name: str,
    db_parameter_group_family: str,
    description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB cluster parameter group. Parameters in a DB cluster parameter group apply to all of the instances in a DB cluster.  A DB cluster parameter group is initially created with the default parameters for the database engine used by instances in the DB cluster. To provide custom values for any of the parameters, you must modify the group after creating it using ModifyDBClusterParameterGroup. Once you've created a DB cluster parameter group, you need to associate it with your DB cluster using ModifyDBCluster. When you associate a new DB cluster parameter group with a running DB cluster, you need to reboot the DB instances in the DB cluster without failover for the new DB cluster parameter group and associated settings to take effect.  After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the DB cluster parameter group is used as the default for a new DB cluster. This is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the character_set_database parameter. You can use the Parameter Groups option of the Amazon Neptune console or the DescribeDBClusterParameters command to verify that your DB cluster parameter group has been created or modified.

    Args:
        db_cluster_parameter_group_name(str): The name of the DB cluster parameter group. Constraints:   Must match the name of an existing DBClusterParameterGroup.    This value is stored as a lowercase string. .
        db_parameter_group_family(str): The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.
        description(str): The description for the DB cluster parameter group.
        tags(List, optional): The tags to be assigned to the new DB cluster parameter group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.create(
                ctx,
                db_cluster_parameter_group_name=value,
                db_parameter_group_family=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.create db_cluster_parameter_group_name=value, db_parameter_group_family=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "DBParameterGroupFamily": db_parameter_group_family,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_cluster_parameter_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified DB cluster parameter group. The DB cluster parameter group to be deleted can't be associated with any DB clusters.

    Args:
        db_cluster_parameter_group_name(str): The name of the DB cluster parameter group. Constraints:   Must be the name of an existing DB cluster parameter group.   You can't delete a default DB cluster parameter group.   Cannot be associated with any DB clusters.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.delete(
                ctx, db_cluster_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.delete db_cluster_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_db_cluster_parameter_group",
        op_kwargs={"DBClusterParameterGroupName": db_cluster_parameter_group_name},
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_parameter_group_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of DBClusterParameterGroup descriptions. If a DBClusterParameterGroupName parameter is specified, the list will contain only the description of the specified DB cluster parameter group.

    Args:
        db_cluster_parameter_group_name(str, optional): The name of a specific DB cluster parameter group to return details for. Constraints:   If supplied, must match the name of an existing DBClusterParameterGroup.  . Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBClusterParameterGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_db_cluster_parameter_groups",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub, ctx, db_cluster_parameter_group_name: str, parameters: List
) -> Dict:
    r"""
    **Autogenerated function**

     Modifies the parameters of a DB cluster parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.  Changes to dynamic parameters are applied immediately. Changes to static parameters require a reboot without failover to the DB cluster associated with the parameter group before the change can take effect.   After you create a DB cluster parameter group, you should wait at least 5 minutes before creating your first DB cluster that uses that DB cluster parameter group as the default parameter group. This allows Amazon Neptune to fully complete the create action before the parameter group is used as the default for a new DB cluster. This is especially important for parameters that are critical when creating the default database for a DB cluster, such as the character set for the default database defined by the character_set_database parameter. You can use the Parameter Groups option of the Amazon Neptune console or the DescribeDBClusterParameters command to verify that your DB cluster parameter group has been created or modified.

    Args:
        db_cluster_parameter_group_name(str): The name of the DB cluster parameter group to modify.
        parameters(List): A list of parameters in the DB cluster parameter group to modify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.modify(
                ctx, db_cluster_parameter_group_name=value, parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.modify db_cluster_parameter_group_name=value, parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="modify_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "Parameters": parameters,
        },
    )


async def reset(
    hub,
    ctx,
    db_cluster_parameter_group_name: str,
    reset_all_parameters: bool = None,
    parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Modifies the parameters of a DB cluster parameter group to the default value. To reset specific parameters submit a list of the following: ParameterName and ApplyMethod. To reset the entire DB cluster parameter group, specify the DBClusterParameterGroupName and ResetAllParameters parameters.  When resetting the entire group, dynamic parameters are updated immediately and static parameters are set to pending-reboot to take effect on the next DB instance restart or RebootDBInstance request. You must call RebootDBInstance for every DB instance in your DB cluster that you want the updated static parameter to apply to.

    Args:
        db_cluster_parameter_group_name(str): The name of the DB cluster parameter group to reset.
        reset_all_parameters(bool, optional): A value that is set to true to reset all parameters in the DB cluster parameter group to their default values, and false otherwise. You can't use this parameter if there is a list of parameter names specified for the Parameters parameter. Defaults to None.
        parameters(List, optional): A list of parameter names in the DB cluster parameter group to reset to the default values. You can't use this parameter if the ResetAllParameters parameter is set to true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.parameter.group.reset(
                ctx, db_cluster_parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.parameter.group.reset db_cluster_parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="reset_db_cluster_parameter_group",
        op_kwargs={
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "ResetAllParameters": reset_all_parameters,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def restore(hub, ctx, fleet_arn: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Moves a domain to ACTIVE status if it was in the INACTIVE status.

    Args:
        fleet_arn(str): The ARN of the fleet.
        domain_name(str): The name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.access.restore(
                ctx, fleet_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.access.restore fleet_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="restore_domain_access",
        op_kwargs={"FleetArn": fleet_arn, "DomainName": domain_name},
    )


async def revoke(hub, ctx, fleet_arn: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Moves a domain to INACTIVE status if it was in the ACTIVE status.

    Args:
        fleet_arn(str): The ARN of the fleet.
        domain_name(str): The name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.access.revoke(
                ctx, fleet_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.access.revoke fleet_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="revoke_domain_access",
        op_kwargs={"FleetArn": fleet_arn, "DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    instance_arn: str,
    description: str = None,
    session_duration: str = None,
    relay_state: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a permission set within a specified SSO instance.  To grant users and groups access to Amazon Web Services account resources, use  CreateAccountAssignment .

    Args:
        name(str): The name of the PermissionSet.
        description(str, optional): The description of the PermissionSet. Defaults to None.
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        session_duration(str, optional): The length of time that the application user sessions are valid in the ISO-8601 standard. Defaults to None.
        relay_state(str, optional): Used to redirect users within the application during the federation authentication process. Defaults to None.
        tags(List, optional): The tags to attach to the new PermissionSet. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.create(
                ctx, name=value, instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.create name=value, instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="create_permission_set",
        op_kwargs={
            "Name": name,
            "Description": description,
            "InstanceArn": instance_arn,
            "SessionDuration": session_duration,
            "RelayState": relay_state,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, instance_arn: str, permission_set_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set that should be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.delete(
                ctx, instance_arn=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.delete instance_arn=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="delete_permission_set",
        op_kwargs={"InstanceArn": instance_arn, "PermissionSetArn": permission_set_arn},
    )


async def describe(hub, ctx, instance_arn: str, permission_set_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details of the permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.describe(
                ctx, instance_arn=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.describe instance_arn=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="describe_permission_set",
        op_kwargs={"InstanceArn": instance_arn, "PermissionSetArn": permission_set_arn},
    )


async def list_all(
    hub, ctx, instance_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the PermissionSets in an SSO instance.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        next_token(str, optional): The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. Defaults to None.
        max_results(int, optional): The maximum number of results to display for the assignment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.list_all(ctx, instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.list_all instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="list_permission_sets",
        op_kwargs={
            "InstanceArn": instance_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def provision(
    hub,
    ctx,
    instance_arn: str,
    permission_set_arn: str,
    target_type: str,
    target_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The process by which a specified permission set is provisioned to the specified target.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set.
        target_id(str, optional): TargetID is an Amazon Web Services account identifier, typically a 10-12 digit string (For example, 123456789012). Defaults to None.
        target_type(str): The entity type for which the assignment will be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.provision(
                ctx, instance_arn=value, permission_set_arn=value, target_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.provision instance_arn=value, permission_set_arn=value, target_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="provision_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "TargetId": target_id,
            "TargetType": target_type,
        },
    )


async def update(
    hub,
    ctx,
    instance_arn: str,
    permission_set_arn: str,
    description: str = None,
    session_duration: str = None,
    relay_state: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set.
        description(str, optional): The description of the PermissionSet. Defaults to None.
        session_duration(str, optional): The length of time that the application user sessions are valid for in the ISO-8601 standard. Defaults to None.
        relay_state(str, optional): Used to redirect users within the application during the federation authentication process. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.permission.set_.init.update(
                ctx, instance_arn=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.permission.set_.init.update instance_arn=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="update_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "Description": description,
            "SessionDuration": session_duration,
            "RelayState": relay_state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def record(
    hub,
    ctx,
    bearer_token: str,
    operation_status: str,
    current_operation_status: str = None,
    status_message: str = None,
    error_code: str = None,
    resource_model: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Reports progress of a resource handler to CloudFormation. Reserved for use by the CloudFormation CLI. Do not use this API in your code.

    Args:
        bearer_token(str): Reserved for use by the CloudFormation CLI.
        operation_status(str): Reserved for use by the CloudFormation CLI.
        current_operation_status(str, optional): Reserved for use by the CloudFormation CLI. Defaults to None.
        status_message(str, optional): Reserved for use by the CloudFormation CLI. Defaults to None.
        error_code(str, optional): Reserved for use by the CloudFormation CLI. Defaults to None.
        resource_model(str, optional): Reserved for use by the CloudFormation CLI. Defaults to None.
        client_request_token(str, optional): Reserved for use by the CloudFormation CLI. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.handler_progress.record(
                ctx, bearer_token=value, operation_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.handler_progress.record bearer_token=value, operation_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="record_handler_progress",
        op_kwargs={
            "BearerToken": bearer_token,
            "OperationStatus": operation_status,
            "CurrentOperationStatus": current_operation_status,
            "StatusMessage": status_message,
            "ErrorCode": error_code,
            "ResourceModel": resource_model,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def describe_all(
    hub,
    ctx,
    filter_: Dict = None,
    locale: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the event types that meet the specified filter criteria. You can use this API operation to find information about the AWS Health event, such as the category, AWS service, and event code. The metadata for each event appears in the EventType object.  If you don't specify a filter criteria, the API operation returns all event types, in no particular order.   This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.

    Args:
        filter_(Dict, optional): Values to narrow the results returned. Defaults to None.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.type_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.type.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_event_types",
        op_kwargs={
            "filter": filter_,
            "locale": locale,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, connection_name: str, provider_type: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Create an AWS App Runner connection resource. App Runner requires a connection resource when you create App Runner services that access private repositories from certain third-party providers. You can share a connection across multiple services. A connection resource is needed to access GitHub repositories. GitHub requires a user interface approval process through the App Runner console before you can use the connection.

    Args:
        connection_name(str): A name for the new connection. It must be unique across all App Runner connections for the AWS account in the AWS Region.
        provider_type(str): The source repository provider.
        tags(List, optional): A list of metadata items that you can associate with your connection resource. A tag is a key-value pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.connection.create(
                ctx, connection_name=value, provider_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.connection.create connection_name=value, provider_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="create_connection",
        op_kwargs={
            "ConnectionName": connection_name,
            "ProviderType": provider_type,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, connection_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an AWS App Runner connection. You must first ensure that there are no running App Runner services that use this connection. If there are any, the DeleteConnection action fails.

    Args:
        connection_arn(str): The Amazon Resource Name (ARN) of the App Runner connection that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.connection.delete(ctx, connection_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.connection.delete connection_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="delete_connection",
        op_kwargs={"ConnectionArn": connection_arn},
    )


async def list_all(
    hub,
    ctx,
    connection_name: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of AWS App Runner connections that are associated with your AWS account.

    Args:
        connection_name(str, optional): If specified, only this connection is returned. If not specified, the result isn't filtered by name. Defaults to None.
        max_results(int, optional): The maximum number of results to include in each response (result page). Used for a paginated request. If you don't specify MaxResults, the request retrieves all available results in a single response. Defaults to None.
        next_token(str, optional): A token from a previous result page. Used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones specified in the initial request. If you don't specify NextToken, the request retrieves the first result page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.connection.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.connection.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="list_connections",
        op_kwargs={
            "ConnectionName": connection_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    application_name: str = None,
    version_label: str = None,
    template_name: str = None,
    environment_id: str = None,
    environment_name: str = None,
    platform_arn: str = None,
    request_id: str = None,
    severity: str = None,
    start_time: str = None,
    end_time: str = None,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns list of event descriptions matching criteria up to the last 6 weeks.  This action returns the most recent 1,000 events from the specified NextToken.

    Args:
        application_name(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those associated with this application. Defaults to None.
        version_label(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this application version. Defaults to None.
        template_name(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that are associated with this environment configuration. Defaults to None.
        environment_id(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment. Defaults to None.
        environment_name(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment. Defaults to None.
        platform_arn(str, optional): The ARN of a custom platform version. If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this custom platform version. Defaults to None.
        request_id(str, optional): If specified, AWS Elastic Beanstalk restricts the described events to include only those associated with this request ID. Defaults to None.
        severity(str, optional): If specified, limits the events returned from this call to include only those with the specified severity or higher. Defaults to None.
        start_time(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur on or after this time. Defaults to None.
        end_time(str, optional):  If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur up to, but not including, the EndTime. . Defaults to None.
        max_records(int, optional): Specifies the maximum number of events that can be returned, beginning with the most recent event. Defaults to None.
        next_token(str, optional): Pagination token. If specified, the events return the next batch of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.event.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.event.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_events",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabel": version_label,
            "TemplateName": template_name,
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "PlatformArn": platform_arn,
            "RequestId": request_id,
            "Severity": severity,
            "StartTime": start_time,
            "EndTime": end_time,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, thing_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the list of all jobs for a thing that are not in a terminal status.

    Args:
        thing_name(str): The name of the thing that is executing the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_jobs_data.pending_job_execution.get_all(
                ctx, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_jobs_data.pending_job_execution.get_all thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-jobs-data",
        operation="get_pending_job_executions",
        op_kwargs={"thingName": thing_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub, ctx, application_name: str, current_application_version_id: int, input_: Dict
) -> Dict:
    r"""
    **Autogenerated function**

     Adds a streaming source to your SQL-based Kinesis Data Analytics application.  You can add a streaming source when you create an application, or you can use this operation to add a streaming source after you create an application. For more information, see CreateApplication. Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.

    Args:
        application_name(str): The name of your existing application to which you want to add the streaming source.
        current_application_version_id(int): The current version of your application. You must provide the ApplicationVersionID or the ConditionalToken.You can use the DescribeApplication operation to find the current application version.
        input_(Dict): The Input to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.input_.init.add(
                ctx, application_name=value, current_application_version_id=value, input_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.input_.init.add application_name=value, current_application_version_id=value, input_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_input",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "Input": input_,
        },
    )
